@@ -18,15 +18,32 @@
 
 from nl.log import logger
 import uuid
-from nl.metanl import Namable
+from nl.metanl import Namable, Subword
 
 class Rule(Namable):
     """
+    A rule is instantiated with a list of premises or antecedents, or tail,
+    and a list of consecuences, or consequents, or head.
+    Both lists can contain objects of type Thing or of type Fact.
+    Additionally, in the list of premises there can be objects of type
+    During, Coincide, Arith and Subword.
+    In the list of consecuences there can be objects of type
+    Finish.
     """
     def __init__(self, prems, cons):
         self.name = uuid.uuid4().get_hex()
         self.prems = prems
         self.cons = cons
+        sane = False
+        for x in xrange(len(self.prems)):
+            if sane:
+                break
+            if isinstance(self.prems[0], Subword):
+                self.prems = self.prems[1:] + [self.prems[0]]
+            else:
+                sane = True
+        if not sane:
+            raise SyntaxError('cannot have only subwords as prems')
 
     def put_action(self, vrs=None):
         """
